@@ -35,7 +35,7 @@ def _next_id() -> int:
 @dataclass
 class ProtocolMessage(Model):
     type: Union[Literal["request", "response", "event"], str]
-    seq: int = field(default_factory=lambda: _next_id())
+    seq: int = field(default_factory=_next_id)
 
 
 @dataclass
@@ -148,10 +148,7 @@ class StoppedReason(Enum):
 
 @dataclass
 class StoppedEventBody(Model):
-    reason: Union[
-        StoppedReason,
-        str,
-    ]
+    reason: Union[StoppedReason, str]
     description: Optional[str] = None
     thread_id: Optional[int] = None
     preserve_focus_hint: Optional[bool] = None
@@ -306,6 +303,7 @@ class InitializeRequestArguments(Model):
     supports_memory_references: Optional[bool] = None
     supports_progress_reporting: Optional[bool] = None
     supports_invalidated_event: Optional[bool] = None
+    supports_a_n_s_i_styling: Optional[bool] = None
 
 
 @dataclass
@@ -398,6 +396,7 @@ class Capabilities(Model):
     supports_stepping_granularity: Optional[bool] = None
     supports_instruction_breakpoints: Optional[bool] = None
     supports_exception_filter_options: Optional[bool] = None
+    supports_a_n_s_i_styling: Optional[bool] = None
 
 
 @dataclass
@@ -524,6 +523,9 @@ class SourceBreakpoint(Model):
     hit_condition: Optional[str] = None
     log_message: Optional[str] = None
 
+    def __hash__(self) -> int:
+        return hash((self.line, self.column, self.condition, self.hit_condition, self.log_message))
+
 
 @dataclass
 class SetBreakpointsArguments(Model):
@@ -620,6 +622,26 @@ class TerminateResponse(Response):
     pass
 
 
+class RestartArguments(Model):
+    arguments: Union[LaunchRequestArguments | AttachRequestArguments]
+
+
+@dataclass
+class _RestartRequest:
+    arguments: Optional[RestartArguments] = None
+
+
+@dataclass
+class RestartRequest(Request, _RestartRequest):
+    arguments: Optional[RestartArguments] = None
+    command: str = "restart"
+
+
+@dataclass
+class RestartResponse(Response):
+    pass
+
+
 @dataclass
 class StackFrameFormat(Model):
     parameters: Optional[bool] = None
@@ -919,7 +941,11 @@ class VariablePresentationHint(Model):
         ]
     ] = None
 
-    visibility: Union[Literal["public", "private", "protected", "internal", "final"], str, None] = None
+    visibility: Union[
+        Literal["public", "private", "protected", "internal", "final"],
+        str,
+        None,
+    ] = None
 
 
 @dataclass
